pub struct Configuration {
pub chain: Url,
pub websocket: WebsocketConf,
pub cache_size: usize,
pub commitment: CommitmentLevel,
}Expand description
General router configuration
Fields
chain: Urlconfiguration of client connections to base chain
websocket: WebsocketConfwebsocket connection pool configuration
cache_size: usizenumber of entries the delegations cache can hold this can be used to restrict memory usage by resolver so that it doesn’t keep unecesary accounts around
commitment: CommitmentLeveldefault commitment level to be used with rpc clients