Resolver

Struct Resolver 

pub struct Resolver { /* private fields */ }
Connection resolver, the type is cheaply clonable and thus a single instance should be initialized and cloned between threads if necessary

Implementations

Source

impl Resolver

pub async fn new(config: Configuration) -> Result<Self, Error>

Initialize the resolver with the provided configuration

pub async fn new_custom( config: Configuration, use_on_chain_routes: bool, custom_routes: Option<HashMap<Pubkey, String>>, ) -> Result<Self, Error>

Initialize the resolver:

  1. fetch routes from chain (if use_on_chain_routes is true)
  2. add custom routes to routing table, if any
  3. subscribe to on-chain route updates (if use_on_chain_routes is true)
  4. creating websocket connection to base chain for delegation status tracking of accounts
pub async fn track_account( &self, pubkey: Pubkey, ) -> Result<DelegationStatus, Error>

Start tracking account’s delegation status, this is achieved by fetching the delegation record for the account (if it exists) and subscribing to updates of its state. The existence of the delegation record is a proof that account has been delegated, and it contains critical information like the identity of validator, to which the account was delegated

pub async fn resolve(&self, pubkey: &Pubkey) -> Result<Arc<RpcClient>, Error>

Resolve connection for given account, if account has been delegated (as observed by resolver), then the returned client is configured to connect to corresponding ER instance, otherwise the client will connect to base layer chain

pub async fn resolve_for_transaction( &self, tx: &Transaction, ) -> Result<Arc<RpcClient>, Error>

Resolve connection for given transaction, if any of the accounts have been delegated (as observed by resolver), then the resolver will check that all the writable accounts in transaction have been delegated to the same ER, if validation is successful, the returned client is configured to connect to this common ER. If none of the accounts are delegated then the returned client is configured to connect to base layer chain. If conflict in delegation is found, i.e. writable accounts are delegated to different ERs, then error is returned as connection resolution is impossible for such a case.